//// [asyncFunctionDeclaration12_es2017.ts]
var v = async function await(): Promise<void> { }

//// [asyncFunctionDeclaration12_es2017.js]
var v = async function () { }, await;
() => { };
